==> kolourpaint-15.12.2.tar.xz: kolourpaint-15.12.2/widgets/imagelib/effects/kpEffectInvertWidget.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpEffectInvertWidget_H
#define kpEffectInvertWidget_H


#include <kpEffectWidgetBase.h>


class QCheckBox;


class kpEffectInvertWidget : public kpEffectWidgetBase
{
Q_OBJECT

public:
    kpEffectInvertWidget (bool actOnSelection,
                          QWidget *parent);
    virtual ~kpEffectInvertWidget ();


    int channels () const;


    //
    // kpEffectWidgetBase interface
    //

    virtual QString caption () const;

    virtual bool isNoOp () const;
    virtual kpImage applyEffect (const kpImage &image);

    virtual kpEffectCommandBase *createCommand (
        kpCommandEnvironment *cmdEnviron) const;

protected slots:
    void slotRGBCheckBoxToggled ();
    void slotAllCheckBoxToggled ();

protected:
    QCheckBox *m_redCheckBox, *m_greenCheckBox, *m_blueCheckBox,
              *m_allCheckBox;

    // blockSignals() didn't seem to work
    bool m_inSignalHandler;
};


#endif  // kpEffectInvertWidget_H

==> kolourpaint-17.08.3.tar.xz: kolourpaint-17.08.3/widgets/imagelib/effects/kpEffectInvertWidget.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpEffectInvertWidget_H
#define kpEffectInvertWidget_H


#include "kpEffectWidgetBase.h"


class QCheckBox;


class kpEffectInvertWidget : public kpEffectWidgetBase
{
Q_OBJECT

public:
    kpEffectInvertWidget (bool actOnSelection,
                          QWidget *parent);
    virtual ~kpEffectInvertWidget ();


    int channels () const;


    //
    // kpEffectWidgetBase interface
    //

    QString caption () const Q_DECL_OVERRIDE;

    bool isNoOp () const Q_DECL_OVERRIDE;
    kpImage applyEffect (const kpImage &image) Q_DECL_OVERRIDE;

    kpEffectCommandBase *createCommand (
        kpCommandEnvironment *cmdEnviron) const Q_DECL_OVERRIDE;

protected slots:
    void slotRGBCheckBoxToggled ();
    void slotAllCheckBoxToggled ();

protected:
    QCheckBox *m_redCheckBox, *m_greenCheckBox, *m_blueCheckBox,
              *m_allCheckBox;

    // blockSignals() didn't seem to work
    bool m_inSignalHandler;
};


#endif  // kpEffectInvertWidget_H
